<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Statistieken van SPIP',
	'stats_nom' => 'Statistieken',
	'stats_slogan' => 'Beheer van de bezoekenstatistieken in SPIP',
];
